%% Finds the indifference level of risk aversion for health, drug and dental
% given a CRRA utility function, lambda, out-of-pocket costs, prices and wage

function f = cutoffs_crra_health(l, oop, ins)
%% cutoffs_crra_health -> crra_diff

% dcrra.hi.opts(m, 6) - coverage tier - nopts+1
% dcrra.hi.opts(m, 1:5) - prices - 1:nopts
% dcrra.hi.opts(m, 7) - average wage - nopts+2

price = ins(1:end-2);
wage = ins(end);
nopts = size(price,2);

for opt1 = 1:(nopts-1)
    for opt2 = (opt1+1):nopts
        price1 = price(opt1);
        price2 = price(opt2);
        oop1 = oop(:, opt1);
        oop2 = oop(:, opt2);
        cons1 = 1 - price1/wage - l*oop1./wage;
        cons2 = 1 - price2/wage - l*oop2./wage;
        
        % if risk neutral always prefers option 2, then option 1 is never
        % chosen, define the cutoff as -10
        if mean(cons1) < mean(cons2)
            cutoff(opt1, opt2) = -10;
            % [mean(cons1), mean(cons2), opt1, opt2]
        % if the consumption in option 1 is ever negative, then option 1 is
        % never chose, define the cutoff as -10
        elseif min(cons1) < 0
            cutoff(opt1, opt2) = -10;

        else
            [cutoff(opt1, opt2),fval,exitflag(1)] = fzero(@(x) crra_diff(l, x, opt1, opt2, oop, ins),1);
        end
    end
end

% check whether most generous option is feasible (i.e. min(cons)>0)
temp = zeros(1,nopts-1);
for t = 1:nopts-1
    temp(t) = min(cutoff(t,t+1:nopts));
    cutoff_interval(t) = max([temp(1:t),0]);
end

% upper cutoff for most generous option
if min(1-price(nopts)/wage-l*oop(:, nopts)./wage) < 0
    cutoff_interval(nopts) = -10;
	
else
    cutoff_interval(nopts) = inf;
end


f = [0, cutoff_interval];
end
