function f = cutoffs(l, ins)

price = ins.price;
oop = ins.oop;

cases = 0;

% number of options in this domain
opts = size(price(1,:),2);

% for each menu, find cutoffs
for m = 1:ins.nmenus
    
    ra_low = zeros(opts);
    ra_high = zeros(opts);
    pos_v = zeros(opts);
    neg_v = zeros(opts);
    
    % for each pair of choices
    for opt1 = 1:opts-1
        for opt2 = (opt1+1):opts
            % find the interval over which there is a sign change
            ra_h = 0.01;
            neutral_ra = cara_diff(l, 0.00000000001,price(m,opt1),price(m,opt2), oop{m}(:,opt1), oop{m}(:,opt2));
            high_ra = cara_diff(l, ra_h,price(m,opt1),price(m,opt2), oop{m}(:,opt1), oop{m}(:,opt2));
            
            if ~isfinite(high_ra)
                %ezplot(@(x)cara_diff(l, x,price(m,opt1),price(m,opt2), oop{m}(:,opt1), oop{m}(:,opt2)), [.0000001,.025]);
                %figure;
                while (~isfinite(high_ra))    % repeat until you find a finite value
                    ra_h = ra_h*.9;
                    high_ra = cara_diff(l, ra_h,price(m,opt1),price(m,opt2), oop{m}(:,opt1), oop{m}(:,opt2));
                end
            end
            
            % computable
            if (neutral_ra>0) && (high_ra<0)
                ra_low(opt1,opt2) = 0;
                ra_high(opt1,opt2) = ra_h;
                pos_v(opt1,opt2) = neutral_ra;
                neg_v(opt1,opt2) = high_ra;
                
                % need higher ra
            elseif (neutral_ra>0) && (high_ra>0)
                while (isfinite(high_ra)) && (high_ra>0)
                    ra_h = ra_h*1.1;
                    high_ra = cara_diff(l, ra_h,price(m,opt1),price(m,opt2), oop{m}(:,opt1), oop{m}(:,opt2));
                end
                if isfinite(high_ra) && high_ra<0
                    pos_v(opt1,opt2) = neutral_ra;
                    neg_v(opt1,opt2) = high_ra;
                    ra_low(opt1,opt2) = 0;
                    ra_high(opt1,opt2)=ra_h;
                    
                else % if none can be found then opt2 is dominated
                    ra_low(opt1,opt2) = inf;
                    ra_high(opt1,opt2)= inf;
                end
                
                
                
                % lower option is dominated
            elseif (neutral_ra<0) && (high_ra<0)
                ra_low(opt1,opt2) = -10;
                ra_high(opt1,opt2)= -10;
                
                
            elseif (neutral_ra<0) && (high_ra>0)
                ezplot(@(x)cara_diff(l, x,price(m,opt1),price(m,opt2), oop{m}(:,opt1), oop{m}(:,opt2)), [.0000001,.025]);
                figure;
                display('error')
            else
                [neutral_ra, high_ra];
            end
            
            if ra_high(opt1,opt2)>0 && ra_high(opt1,opt2)<10 % valid values - start searching for indifference point
                z = 0;
                while abs(ra_low(opt1,opt2)-ra_high(opt1,opt2))>10^(-9) && (z<400)
                    z = z+1;
                    trial = (ra_low(opt1,opt2)+ra_high(opt1,opt2))/2;
                    value = cara_diff(l, trial,price(m,opt1),price(m,opt2), oop{m}(:,opt1), oop{m}(:,opt2));
                    if value >= 0
                        ra_low(opt1,opt2) = trial;
                        pos_v(opt1,opt2) = value;
                    elseif value<0
                        ra_high(opt1,opt2) = trial;
                        neg_v(opt1,opt2) = value;
                    else
                        display('error')
                    end
                end
            end
            
        end
    end
    
    temp = zeros(1,opts-1);
    for t = 1:opts-1
        temp(t) = min(ra_low(t,t+1:opts));
        cutoff(m,t) = max([temp(1:t),0]);
    end
end

for m = 1:ins.nmenus
    A(m,:) = [0,cutoff(m,:),inf];
end

f = A;
end
