%% Reads in data and saves it in a nice structure
function data = loadData(rect)
  %rect = csvread(file);
  data.N = size(rect,1); % number of observations
  
  lhprice = 18:22; % location of HI prices
  lhoop = 13:17; 	% location of predicted oop under each plan
  lhmenu = 59; 		% location of plan number
  lhcovgtier = 24;	% location of coverage tier
  lhchoice = 41;	% location of HI choice
  
  lroop = 29:31;	% location of RX oop
  lrprice = 32:34; % location of RX prices
  lrmenu = 60; 		% location of plan number
  lrcovgtier = 35; 	% location of RX covg tier
  lrchoice = 42; 	% location of rX choice
  
  ldoop = 36:37; 	% location of dental oop
  ldprice = 38:39;	% location of dental prices
  ldmenu = 61; 		% location of plan number
  ldcovgtier = 40; 	% location of dental cog tier
  ldchoice = 43; 	% location of dental choice
  
  lstdprice = 47:49; % location of STDI prices
  lstdopts = 44:46; % location of STDI coverage options
  lstdshock = 2; % location of STDI shock
  lstdmenu = 3; % location of STDI menu for given person
  lstdchoice = 4; % location of STDI choice

  lltdprice = 53:55; % location of LTDI prices
  lltdopts = 50:52; % location of LTDI coverage options
  lltdmenu = 6; % location of LTDI menu
  lltdshock1 = 5; % location of LTDI shock for first year
  lltdshock = 9:11; % location of LTDI shock for other years
  lltdchoice = 7; % location of LTDI choice
  
  lfinrfree = 25; %location of 401k allocation rfree_cont
  
  lwage = 23;
  lwage_group = 72;
  lwage_avg = 73;
  
  leqshare = 57;
  leqamt = 58;

  % health
  data.hi.price = rect(:,lhprice);
  data.hi.oop = rect(:, lhoop);
%   data.hi.menu = rect(:, lhmenu);
  data.hi.covgtier = rect(:, lhcovgtier);
  data.hi.choice = rect(:, lhchoice);
  
  % drug
  data.rx.oop = rect(:, lroop);
%   data.rx.menu = rect(:, lrmenu);
  data.rx.price = rect(:, lrprice);
  data.rx.covgtier = rect(:, lrcovgtier);
  data.rx.choice = rect(:, lrchoice);
  
  % dental
  data.dental.oop = [rect(:, ldoop(1))-rect(:, ldoop(2)), rect(:, ldoop(2))-rect(:, ldoop(2))];
%   data.dental.menu = rect(:, ldmenu);
  data.dental.price = [rect(:, ldprice(1))-rect(:, ldprice(1)), rect(:, ldprice(2))-rect(:, ldprice(1))];
  data.dental.covgtier = rect(:, ldcovgtier);
  data.dental.choice = rect(:, ldchoice);
  % stdi
  data.std.price = rect(:, lstdprice);
  data.std.opts = rect(:, lstdopts)./100;
  
  data.std.shock = rect(:, lstdshock)/365;
%   data.std.menu = rect(:, lstdmenu);
%   data.std.caramenu = rect(:, 74);
  data.std.choice = rect(:,lstdchoice);      								% STD choice 1,2,3 from the menu
  
  %ltdi
  data.ltd.price = rect(:, lltdprice);
  data.ltd.opts = rect(:, lltdopts)/100;
%   data.ltd.menu = rect(:, lltdmenu);
%   data.ltd.caramenu = rect(:, 75);
  
  data.ltd.shock = [min(rect(:,lltdshock1), 365)/365, rect(:,lltdshock)]; 	% actual # of days for 2004; use 0/1 if on Leave of absence
  data.ltd.choice = rect(:,lltdchoice);     								% LTD choice 1,2,3 from the menu
  
  %401k
  data.fin.rfree = rect(:, lfinrfree);
  data.fin.bal = rect(:, 62);
  data.fin.choice = data.fin.rfree;
  data.fin.choice(data.fin.rfree==0) = 1;
  data.fin.choice(data.fin.rfree==1) = 3;
  data.fin.choice(data.fin.rfree~=0 & data.fin.rfree~=1) = 2;
  data.fin.constrained= rect(:, 56);
  %tabulate(data.fin.choice);

  % Data needed for overlap - actual sample info
  data.wage = rect(:,lwage);					
  data.wage_group = rect(:,lwage_group);					
  data.wage_avg = rect(:,lwage_avg);					
  % data.wage_bal = data.wage_avg + data.fin.bal/20;
  data.wage_bal_avg = rect(:,77);					
  
  % housing
  data.housing.eqshare = rect(:, leqshare);
  data.housing.Neqshare0 = sum(data.housing.eqshare==0);
  data.housing.Neqshare1 = sum(data.housing.eqshare==1);
  data.housing.Neqshare2 = sum(data.housing.eqshare==2);
  data.housing.eqamt = rect(:, leqamt);
  data.housing.Neqamt1 = sum(data.housing.eqamt==1);
  data.housing.Neqamt2 = sum(data.housing.eqamt==2);
  data.housing.Neqamt3 = sum(data.housing.eqamt==3);
  data.housing.eq = rect(:, 63);
  
  data.sample.max_match = rect(:, 64), 
  data.sample.single = rect(:,65);
  data.sample.newhire = rect(:, 66);
  data.sample.highwage = rect(:, 67);
  data.sample.alcoacont = rect(:, 68);
  data.sample.rebalance = rect(:, 69);
  data.sample.over55 = rect(:, 70);
  data.sample.salaried = rect(:, 71);
  
  
  
  
  end
