clear all
set more off
capture log close

set mem 1g

local c_date = c(current_date)
local c_date = subinstr("`c_date'", " ", "_", .)
log using ../log/ordered_probit_`c_date', text replace

* save the correlation and add the standard errors
capture program drop add_se
program define add_se
	local nobs = `2'
	matrix define R = `1'
	matrix A = J(2*rowsof(R)+1,colsof(R),.)
	local rows = 2*rowsof(R)
	local cols = colsof(R)

	forval j = 1/`cols' {
		forval i = 1/`cols' {
						
			if (`i'>`j') { 
				* variances are 1 except for the 401k
				matrix A[2*`i'-1,`j'] = R[`i',`j']/(sqrt(R[`i',`i'])* sqrt(R[`j',`j']))
			}
			
			if (`i'>`j') {
				qui: nlcom tanh([atanhrho_`j'`i']_cons)
				matrix V = r(V)
				local se = sqrt(V[1,1])
				matrix A[2*`i',`j'] = 2*normal(-abs(A[2*`i'-1,`j']/`se'))
			}
			
			}
	}
	
	matrix A[2*rowsof(R)+1,1] = `nobs'
	matrix final = A[3..`rows'+1, 1..`cols'-1]
end


cmp setup 

use ../dta_pub/sample_080911.dta, replace

bys allmenu: gen menu_count = _N
drop if menu_count < 100
xi i.allmenu, prefix(M)

* TABLE 3(A) - Panel B 
* ***********************************************************
cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) (rfree_cont = M*), ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(100) nodrop nolrtest
matrix define results = e(Sigma)
matrix list results
add_se results e(N)
matrix list final
matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
matrix list final

* T4(a)  comparison by Xs  ordered probit
* ***********************************************************
local i = 0
matrix define results = J(21,9,.)

gen wage_high = 1 if wage_amt_hr>72000
replace wage_high = 0 if wage_amt_hr<36000
gen age_old = 1 if age>=55
replace age_old = 0 if age<=35
gen no_alcoa_cont = !alcoa_cont
gen salaried = !hourly

foreach var of varlist single new_hired_new wage_high no_alcoa_cont rebalance age_old salaried  {
	preserve
	keep if `var' == 1
	bys allmenu: gen nobs = _N
	drop if nobs < 10
	drop M*
	xi i.allmenu, prefix(M)
	
	matrix define table5 = J(2,5,.)
	local name = subinstr("`var'", "_", " ",.)
	
	cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) (rfree_cont = M*) if `var' == 1, ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(10) nodrop nolrtest
	matrix define results = e(Sigma)
	local nobs = e(N)
	add_se results `nobs'
	matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
	matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
	outtable using ../output_pub/table4a_oprobit, mat(final) replace center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, `name' == 1;") nobox
	matrix drop results
	matrix CR = final
	matrix list final
	
	* nobs
	matrix table5[1,1]=`nobs'
	* avg correlation
	matrix table5[1,2]= (CR[1,1] + CR[3,1] + CR[3,2] + CR[5,1] + CR[5,2] + CR[5,3] + CR[7,1] + CR[7,2] + CR[7,3] + CR[7,4] + CR[9,1] + CR[9,2] + CR[9,3] + CR[9,4] + CR[9,5])/15 
	* HI & drug
	matrix table5[1,3]=CR[1,1]
	* HI & DI
	matrix table5[1,4]=CR[5,1]
	* 401(k) & HI
	matrix table5[1,5]=CR[9,1]
	matrix drop CR
	restore
	
	preserve
	keep if `var' == 0
	bys allmenu: gen nobs = _N
	drop if nobs < 10
	xi i.allmenu 
		
	cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) (rfree_cont = M*) if `var' == 0, ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(10) nodrop nolrtest
	matrix define results = e(Sigma)
	local nobs = e(N)
	add_se results e(N)
	matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
	matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
	outtable using ../output_pub/table4a_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, `name' == 0;") nobox
	matrix CR = final
	matrix list final
	
	* nobs
	matrix table5[2,1]=`nobs'
	* avg correlation
	matrix table5[2,2]= (CR[1,1] + CR[3,1] + CR[3,2] + CR[5,1] + CR[5,2] + CR[5,3] + CR[7,1] + CR[7,2] + CR[7,3] + CR[7,4] + CR[9,1] + CR[9,2] + CR[9,3] + CR[9,4] + CR[9,5])/15 
	* HI & drug
	matrix table5[2,3]=CR[1,1]
	* HI & DI
	matrix table5[2,4]=CR[5,1]
	* 401(k) & HI
	matrix table5[2,5]=CR[9,1]
	matrix list table5
	
	matrix colnames table5 = "Obs" "AvgCorr" "Health-Drug" "Health-STD" "Health-401k"
	outtable using ../output_pub/table4a_oprobit, mat(table5) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f)  nobox
	restore
}

* TABLE 6 - PANEL B
* ***********************************************************

local i = 0
matrix define results = J(7,9,.)

gen housing_sample = 1 if equity_share !=.
recode avl_equity (0/50000 = 1 "1-less than 50k") (50000/150000 = 2 "2-50k to 150k") (150000/1000000000 = 3 "3-more than 150k") if housing_sample==1, gen(avl_equity_recode)

foreach condition in "housing_sample==1" "avl_equity_recode==1" "avl_equity_recode==2" "avl_equity_recode==3" "constr_401k==0" "constr_401k==1" {
	preserve
	keep if `condition'
	bys allmenu: gen nobs = _N
	drop if nobs < 10
	drop M*
	xi i.allmenu, prefix(M)

	local i = `i' + 1
	cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) (rfree_cont = M*), ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(10) nodrop nolrtest
	matrix define results = e(Sigma)
	local nobs = e(N)
	add_se results e(N)
	matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
	matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
	outtable using ../output_pub/table6b_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, `name' == 0;") nobox
	matrix list final
	restore
}

matrix colnames results = "Avg_corr" "HI-Rx" "HI-STDI" "401k-HI" "401k-Drug" "401k-Dental" "401k-STDI" "401k-LTDI" "N"
matrix rownames results = "WholeSample" "HousingSample" "Eq-less-50k" "Eq-50-150" "Eq-above-150" "401k-not-const" "401k-constr"
matrix list results, format(%9.3g)

* Robustness
* Table 5 - Different specifications
* ***********************************************************
* 1 - Baseline - above

* 2 - discretize 401k - 20% brackets of investment
recode rfree_cont (min/.01 = 1) (.01/.99 = 2) (.99/max = 3), gen(rfree_recode)
cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) (rfree_recode = M*), ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit) ghkdraws(100) nodrop  nolrtest
	matrix define results = e(Sigma)
	add_se results e(N)
	matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
	matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
	outtable using ../output_pub/table5_oprobit, mat(final) replace center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, discrete 401k") nobox
	matrix list final

* 3 - coverage tier FE
xi i.covg_tierrecode, prefix(Icov)
cmp (hi_ord = M* Icov*) (drug_ord = M* Icov*) (dental_ord = M* Icov*) (stdi_ord = M* Icov*) (ltd_ord = M* Icov*) (rfree_cont = M* Icov*), ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(100) nodrop  nolrtest
	matrix define results = e(Sigma)
	add_se results e(N)
	matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
	matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
	outtable using ../output_pub/table5_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, covg tier FE") nobox
	matrix list final
	
* 4 - only largest pricing menu
* largest menu - constants only
cmp (hi_ord = ) (drug_ord = ) (dental_ord = ) (stdi_ord = ) (ltd_ord = ) (rfree_cont = ) if allmenu == 52481 , ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(100) nodrop  nolrtest
matrix define results = e(Sigma)
add_se results e(N)
matrix list final
matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
matrix list final
outtable using ../output_pub/table5_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, largest pricing menu") nobox
matrix list final

* Part 2 - Alternative samples
* ***********************************************************
* 8 - exclude Select 1
* 9 - only new hires 
* 10 - exclude possible default options

* 8 - exclude Select 1
* exclude select 1
qui: cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) (rfree_cont = M*) if planrecode!=10 , ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(100) nodrop  nolrtest
matrix define results = e(Sigma)
add_se results e(N)
matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
matrix list final
outtable using ../output_pub/table5_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, without Select 1 plan") nobox

* 9 - new-hires
cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) (rfree_cont = M*) if new_hired_new , ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(100) nodrop  nolrtest
matrix define results = e(Sigma)
add_se results e(N)
matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
matrix list final
outtable using ../output_pub/table5_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, new hires") nobox

* 10 - exclude default - 
cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) (rfree_cont = M*) if !default, ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(100) nodrop  nolrtest
matrix define results = e(Sigma)
add_se results e(N)
matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI" "se" "401k" "se" "N"
matrix list final
outtable using ../output_pub/table5_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, default choices") nobox

* 5 - include opt-out and HMO
* 6 - include 401k non-contributors
* 7 - include LTD not offered
* for 5,6,7 we need a different sample that doesn't exclude the HMO, opt-out, 401k non-contributors and employees not offered LTD
clear
use ../dta/clean_sample_full
gen deviations = hmo_opt_out + non_contrib + ltd_not_offered
tab deviations
keep if deviations < 2

* 5 - include opt-out and HMO - all correlations except for HI, drug
preserve
keep if deviations == 0 | hmo_opt_out
bys allmenu: gen nobs = _N
drop if nobs <10
drop M*
xi i.allmenu, prefix(M)
cmp (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) (rfree_cont = M*) if deviations == 0 | hmo_opt_out, ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(100) nodrop  nolrtest
matrix define results = e(Sigma)
add_se results e(N)
matrix colnames final = "Dental" "STDI" "LTDI"
matrix rownames final = "STDI" "se" "LTDI" "se" "401k" "se" "N"
matrix list final
outtable using ../output_pub/table5_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, include opt-out and HMO, all correlations except for HI and drug") nobox
restore

* 6 - include 401k non-contrib
preserve
keep if deviations == 0 | non_contrib
bys allmenu: gen nobs = _N
drop if nobs < 50
drop M*
xi i.allmenu, prefix(M)
cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (ltd_ord = M*) if deviations==0 | non_contrib, ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit) ghkdraws(100) nodrop  
matrix define results = e(Sigma)
add_se results e(N)
matrix colnames final = "HI" "Drug" "Dental" "STDI"
matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "LTDI"  "N"
matrix list final
outtable using ../output_pub/table5_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, 401k non contributors") nobox
restore

* 7 - include not offered LTD
preserve
keep if deviations==0 | ltd_not_offered
bys allmenu: gen nobs = _N
drop if nobs <20
drop M*
xi i.allmenu, prefix(M)
cmp (hi_ord = M*) (drug_ord = M*) (dental_ord = M*) (stdi_ord = M*) (rfree_cont = M*) if if deviations==0 | ltd_not_offered, ind($cmp_oprobit  $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont) ghkdraws(100) nodrop  nolrtest
matrix define results = e(Sigma)
add_se results e(N)
matrix colnames final = "HI" "Drug" "Dental" "STDI" 
matrix rownames final = "Drug" "se" "Dental" "se" "STDI" "se" "401k" "se" "N"
matrix list final
outtable using ../output_pub/table5_oprobit, mat(final) append center f(%9.3f %9.3f %9.3f %9.3f %9.3f) caption("Ordered Probit, Menu FE, LTD not offered") nobox
restore

capture log close
