
capture log close
set more off
clear mata
capture clear matrix

set mem 2g

local c_date = c(current_date)
local c_date = subinstr("`c_date'", " ", "_", .)
log using ../log/table3b_a_`c_date', text replace

cmp setup 

global demog = "age age_sq female white hourly tenure_hr wage_amt_hr single"
global pr_risk = "total_xb rx_total_xb dental_total_xb std_days_xb ltd_days_xb"
global risk = "total rx_total dental_total std_days ltd_days"

use ../dta/sample_080911, clear

* PROGRAM - save the correlation and add the standard errors

capture program drop add_se
program define add_se
	local nobs = `2'
	matrix define R = `1'
	matrix A = J(2*rowsof(R)+1,colsof(R),.)
	local rows = 2*rowsof(R)
	local cols = colsof(R)

	forval j = 1/`cols' {
		forval i = 1/`cols' {
			di `i' `j'
			
			if (`i'>`j') { 
				* variances are 1 except for the 401k
				matrix A[2*`i'-1,`j'] = R[`i',`j']/(sqrt(R[`i',`i'])* sqrt(R[`j',`j']))
			}
			
			if (`i'>`j') {
				qui: nlcom tanh([atanhrho_`j'`i']_cons)
				matrix V = r(V)
				local se = sqrt(V[1,1])
				matrix A[2*`i',`j'] = 2*normal(-abs(A[2*`i'-1,`j']/`se'))
			}
			
			}
	}
	
	matrix A[2*rowsof(R)+1,1] = `nobs'
	matrix final = A[3..`rows'+1, 1..`cols'-1]
end

* **************************************************
* MAIN CODE
* **************************************************

* * Table 3a - fixed effects, predicted and realized risk and risk score

set seed 32819

matrix define results = J(30, 18,.)
matrix colnames results = iter size hi_rx hi_dental hi_std hi_ltd hi_401k rx_dental rx_std rx_ltd rx_401k dental_std dental_ltd dental_401k std_ltd std_401k ltd_401k converged

local j = 0

forval i = 1/40 {
	preserve
	bsample
		drop *xb _I*
		bys allmenu: gen menu_count = _N
		drop if menu_count < 100
		count
		xi i.allmenu, prefix(M)

			foreach var in total rx_total dental_total std_days ltd_days {
				qui xi: reg `var' *spline* female hourly  white union single family_size age_single age_female age_hourly over65 i.state_loc
				predict `var'_xb, xb
			}
					
			capture noisily cmp (hi_ord = M* $risk $pr_risk rs_fam) (drug_ord = M* $risk $pr_risk rs_fam) (dental_ord = M* $risk $pr_risk rs_fam) (stdi_ord = M* $risk $pr_risk rs_fam) (ltd_ord = M* $risk $pr_risk rs_fam) (rfree_cont = M* $risk $pr_risk rs_fam), ind($cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_oprobit $cmp_cont)  ghkdraws(25) ghkanti nodrop nolrtest iterate(15)
			
			di "error code: " _rc
			
			if _rc == 0 {
			matrix define covar = e(Sigma)
			add_se covar e(N)
							
			* the matrix with results is called final
			matrix results[`j', 1] = `i'
			matrix results[`j', 2] = e(N)
			matrix results[`j', 3] = final[1,1]
			matrix results[`j', 4] = final[3,1]
			matrix results[`j', 5] = final[5,1]
			matrix results[`j', 6] = final[7,1]
			matrix results[`j', 7] = final[9,1]
			matrix results[`j', 8] = final[3,2]
			matrix results[`j', 9] = final[5,2]
			matrix results[`j', 10] =final[7,2]
			matrix results[`j', 11] = final[9,2]
			matrix results[`j', 12] = final[5,3]
			matrix results[`j', 13] = final[7,3]
			matrix results[`j', 14] = final[9,3]
			matrix results[`j', 15] = final[7,4]
			matrix results[`j', 16] = final[9,4]
			matrix results[`j', 17] = final[9,5]
			matrix results[`j', 18] = e(converged)
			matrix list results      
			outtable using ../output/oprobit_bootstrap_`F', mat(results) replace center f(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) caption("`F' - Boostrapped Ordered Probit, Risk Score, Menu FE, Predicted and Realized Risk") nobox
			}
	restore
}

drop *
svmat results, names(col)
drop if converged == . | converged == 0

* keep the first 25 estimations that have conveged
keep in 1/25
count

sum

foreach v of varlist * {
	gen p_`v' = (`v'<0)
	}

sum
capture log close

